==> icn-8.x-1.0.tar.gz: icn/src/Form/IcnDefault.php <==
<?php

namespace Drupal\icn\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Path\AliasManagerInterface;
use Drupal\Core\Routing\RequestContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class IcnDefault.
 */
class IcnDefault extends ConfigFormBase {
    
  /**
   * The path alias manager.
   *
   * @var \Drupal\Core\Path\AliasManagerInterface
   */
  protected $aliasManager;

  /**
   * The request context.
   *
   * @var \Drupal\Core\Routing\RequestContext
   */
  protected $requestContext;

    
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'icn.default',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'icn_default';
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('path.alias_manager'),
      $container->get('router.request_context')
    );
  }

  /**
   * Constructs a SiteInformationForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Path\AliasManagerInterface $alias_manager
   *   The path alias manager.
   * @param \Drupal\Core\Routing\RequestContext $request_context
   *   The request context.
   */
  public function __construct(ConfigFactoryInterface $config_factory, PathValidatorInterface $path_validator, RequestContext $request_context) {
    parent::__construct($config_factory);

    $this->aliasManager = $alias_manager;
    $this->requestContext = $request_context;
  }

  
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $defaults = $this->config('icn.default')->get('default', []);
    $number_default = $form_state->getValue('number_default', count($defaults));
    $removed = $form_state->getValue('removed_default', []);
 
    $form['number_default'] = [
      '#type' => 'value',
      '#value' => $number_default,
    ];
    $form['removed'] = [
      '#type' => 'value',
      '#value' => $removed,
    ];
    $form['default'] = [
      '#type' => 'fieldset',
      '#title' => t("Default Links"),
      '#tree' => TRUE,
    ];
    for ($i = 1; $i <= $number_default; $i++) {
      $item = array_shift($defaults);
      if (in_array($i, $removed)) {continue;}
      
      $form['default'][$i] = $this->addFieldGroup($i,$item);
    }
    
    $form['default'][$i+1] = $this->addFieldGroup($i+1, [], FALSE);
    
    $form['default']['add_item'] = [
      '#type' => 'submit',
      '#value' => t('Add item'),
      '#submit' => ['::addItem'],
    ];
 
    return parent::buildForm($form, $form_state);
  }
 
  public function addItem(array &$form, FormStateInterface $form_state) {
    $form_state->setValue('number_default', $form_state->getValue('number_default') + 1);
    $form_state->setRebuild();
  }
 
  public function removeItem(array &$form, FormStateInterface $form_state) {
    $removed = $form_state->getValue('number_default', []);
    $removed[] = $form_state->getTriggeringElement()['#attributes']['data-toRemove'];
    $form_state->setValue('number_default', $removed);
    $form_state->setRebuild();
  }
 
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $parsed = [];
    $values = $form_state->getValue('default');
    foreach ($values as $value) {
        if($value['title'] == '' && $value['url'] == '') {
            continue;
        }
        $data_item = ['title' => $value['title'], 'url' => $this->aliasManager->getPathByAlias($value['url'])];
        $data[] = $data_item;
    }
    $this->config('icn.default')->set('default', $data)->save();
  }

  protected function addFieldGroup($i, $default = [], $withRemove = TRUE) {
      $fieldgroup = [
        '#type' => 'fieldset',
      ];
       
      $fieldgroup['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => isset($default['title']) ? $default['title'] : '',
        ];
      
      $fieldgroup['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path'),
      '#default_value' => (isset($default['url'])) ? $default['url'] : '',
      '#field_prefix' => $this->requestContext->getCompleteBaseUrl(),
        ];
      
      if($withRemove === TRUE) {
        $fieldgroup['remove_' . $i] = [
          '#type' => 'submit',
          '#value' => t("Delete me"),
          '#submit' => ['::removeItem'],
          '#attributes' => [
            'class' => ['button--danger'],
            'data-toRemove' => $i,
          ]
        ];                
      }
      
      return $fieldgroup;
  }
}

==> icn-8.x-1.1.tar.gz: icn/src/Form/IcnDefault.php <==
<?php

namespace Drupal\icn\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Path\AliasManagerInterface;
use Drupal\Core\Routing\RequestContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class IcnDefault.
 */
class IcnDefault extends ConfigFormBase {
    
  /**
   * The path alias manager.
   *
   * @var \Drupal\Core\Path\AliasManagerInterface
   */
  protected $aliasManager;

  /**
   * The request context.
   *
   * @var \Drupal\Core\Routing\RequestContext
   */
  protected $requestContext;

    
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'icn.default',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'icn_default';
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('path.alias_manager'),
      $container->get('router.request_context')
    );
  }

  /**
   * Constructs a SiteInformationForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Path\AliasManagerInterface $alias_manager
   *   The path alias manager.
   * @param \Drupal\Core\Routing\RequestContext $request_context
   *   The request context.
   */
  public function __construct(ConfigFactoryInterface $config_factory, AliasManagerInterface $alias_manager, RequestContext $request_context) {
    parent::__construct($config_factory);

    $this->aliasManager = $alias_manager;
    $this->requestContext = $request_context;
  }

  
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $defaults = $this->config('icn.default')->get('default', []);
    $number_default = $form_state->getValue('number_default', count($defaults));
    $removed = $form_state->getValue('removed_default', []);
 
    $form['number_default'] = [
      '#type' => 'value',
      '#value' => $number_default,
    ];
    $form['removed'] = [
      '#type' => 'value',
      '#value' => $removed,
    ];
    $form['default'] = [
      '#type' => 'fieldset',
      '#title' => t("Default Links"),
      '#tree' => TRUE,
    ];
    for ($i = 1; $i <= $number_default; $i++) {
      $item = array_shift($defaults);
      if (in_array($i, $removed)) {continue;}
      
      $form['default'][$i] = $this->addFieldGroup($i,$item);
    }
    
    $form['default'][$i+1] = $this->addFieldGroup($i+1, [], FALSE);
    
    $form['add_item'] = [
      '#type' => 'submit',
      '#value' => t('Add item'),
      '#submit' => ['::addItem'],
    ];
 
    return parent::buildForm($form, $form_state);
  }
 
  public function addItem(array &$form, FormStateInterface $form_state) {
    $form_state->setValue('number_default', $form_state->getValue('number_default') + 1);
    $form_state->setRebuild();
  }
 
  public function removeItem(array &$form, FormStateInterface $form_state) {
    $removed = $form_state->getValue('number_default', []);
    $removed[] = $form_state->getTriggeringElement()['#attributes']['data-toRemove'];
    $form_state->setValue('number_default', $removed);
    $form_state->setRebuild();
  }
 
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $parsed = [];
    $values = $form_state->getValue('default');
    foreach ($values as $value) {
        if($value['title'] == '' && $value['url'] == '') {
            continue;
        }
        $data_item = ['title' => $value['title'], 'url' => $this->aliasManager->getPathByAlias($value['url'])];
        $data[] = $data_item;
    }
    $this->config('icn.default')->set('default', $data)->save();
  }

  protected function addFieldGroup($i, $default = [], $withRemove = TRUE) {
      $fieldgroup = [
        '#type' => 'fieldset',
      ];
       
      $fieldgroup['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => isset($default['title']) ? $default['title'] : '',
        ];
      
      $fieldgroup['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path'),
      '#default_value' => (isset($default['url'])) ? $default['url'] : '',
      '#field_prefix' => $this->requestContext->getCompleteBaseUrl(),
        ];
      
      if($withRemove === TRUE) {
        $fieldgroup['remove_' . $i] = [
          '#type' => 'submit',
          '#value' => t("Delete me"),
          '#submit' => ['::removeItem'],
          '#attributes' => [
            'class' => ['button--danger'],
            'data-toRemove' => $i,
          ]
        ];                
      }
      
      return $fieldgroup;
  }
}
